@@ -6,6 +6,8 @@ from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
+from ..models.record_state import check_record_state
+from ..models.record_state import RecordState
 from ..types import UNSET, Unset
 from dateutil.parser import isoparse
 from typing import cast
@@ -14,9 +16,9 @@ from typing import Union
 import datetime
 
 if TYPE_CHECKING:
-  from ..models.record_relation_dto import RecordRelationDto
   from ..models.record_authorization_dto import RecordAuthorizationDto
   from ..models.create_record_command_tags import CreateRecordCommandTags
+  from ..models.record_relation_dto import RecordRelationDto
 
 
 
@@ -41,6 +43,8 @@ class CreateRecordCommand:
             labels (Union[Unset, list[str]]):
             tags (Union[Unset, CreateRecordCommandTags]):
             authorization (Union[Unset, RecordAuthorizationDto]):
+            state (Union[Unset, RecordState]):
+            batch_process (Union[Unset, bool]):
      """
 
     title: Union[Unset, str] = UNSET
@@ -54,15 +58,17 @@ class CreateRecordCommand:
     labels: Union[Unset, list[str]] = UNSET
     tags: Union[Unset, 'CreateRecordCommandTags'] = UNSET
     authorization: Union[Unset, 'RecordAuthorizationDto'] = UNSET
+    state: Union[Unset, RecordState] = UNSET
+    batch_process: Union[Unset, bool] = UNSET
 
 
 
 
 
     def to_dict(self) -> dict[str, Any]:
-        from ..models.record_relation_dto import RecordRelationDto
         from ..models.record_authorization_dto import RecordAuthorizationDto
         from ..models.create_record_command_tags import CreateRecordCommandTags
+        from ..models.record_relation_dto import RecordRelationDto
         title = self.title
 
         description: Union[None, Unset, str]
@@ -118,6 +124,13 @@ class CreateRecordCommand:
         if not isinstance(self.authorization, Unset):
             authorization = self.authorization.to_dict()
 
+        state: Union[Unset, int] = UNSET
+        if not isinstance(self.state, Unset):
+            state = self.state
+
+
+        batch_process = self.batch_process
+
 
         field_dict: dict[str, Any] = {}
 
@@ -145,6 +158,10 @@ class CreateRecordCommand:
             field_dict["tags"] = tags
         if authorization is not UNSET:
             field_dict["authorization"] = authorization
+        if state is not UNSET:
+            field_dict["state"] = state
+        if batch_process is not UNSET:
+            field_dict["batchProcess"] = batch_process
 
         return field_dict
 
@@ -152,9 +169,9 @@ class CreateRecordCommand:
 
     @classmethod
     def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
-        from ..models.record_relation_dto import RecordRelationDto
         from ..models.record_authorization_dto import RecordAuthorizationDto
         from ..models.create_record_command_tags import CreateRecordCommandTags
+        from ..models.record_relation_dto import RecordRelationDto
         d = dict(src_dict)
         title = d.pop("title", UNSET)
 
@@ -245,6 +262,18 @@ class CreateRecordCommand:
 
 
 
+        _state = d.pop("state", UNSET)
+        state: Union[Unset, RecordState]
+        if isinstance(_state,  Unset):
+            state = UNSET
+        else:
+            state = check_record_state(_state)
+
+
+
+
+        batch_process = d.pop("batchProcess", UNSET)
+
         create_record_command = cls(
             title=title,
             description=description,
@@ -257,6 +286,8 @@ class CreateRecordCommand:
             labels=labels,
             tags=tags,
             authorization=authorization,
+            state=state,
+            batch_process=batch_process,
         )
 
         return create_record_command
