@@ -6,6 +6,8 @@ from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
+from ..models.record_state import check_record_state
+from ..models.record_state import RecordState
 from ..types import UNSET, Unset
 from dateutil.parser import isoparse
 from typing import cast
@@ -15,9 +17,9 @@ import datetime
 
 if TYPE_CHECKING:
   from ..models.record_attachment_dto import RecordAttachmentDto
-  from ..models.record_relation_dto import RecordRelationDto
-  from ..models.record_authorization_dto import RecordAuthorizationDto
   from ..models.record_dto_tags import RecordDtoTags
+  from ..models.record_authorization_dto import RecordAuthorizationDto
+  from ..models.record_relation_dto import RecordRelationDto
 
 
 
@@ -39,9 +41,8 @@ class RecordDto:
             event_date (Union[None, Unset, datetime.datetime]):
             created_by (Union[Unset, str]):
             updated_by (Union[None, Unset, str]):
-            searchable (Union[Unset, bool]):
+            state (Union[Unset, RecordState]):
             ttl (Union[None, Unset, int]):
-            archived (Union[Unset, bool]):
             schema (Union[Unset, Any]):
             content (Union[Unset, Any]):
             attachments (Union[Unset, list['RecordAttachmentDto']]):
@@ -60,9 +61,8 @@ class RecordDto:
     event_date: Union[None, Unset, datetime.datetime] = UNSET
     created_by: Union[Unset, str] = UNSET
     updated_by: Union[None, Unset, str] = UNSET
-    searchable: Union[Unset, bool] = UNSET
+    state: Union[Unset, RecordState] = UNSET
     ttl: Union[None, Unset, int] = UNSET
-    archived: Union[Unset, bool] = UNSET
     schema: Union[Unset, Any] = UNSET
     content: Union[Unset, Any] = UNSET
     attachments: Union[Unset, list['RecordAttachmentDto']] = UNSET
@@ -78,9 +78,9 @@ class RecordDto:
 
     def to_dict(self) -> dict[str, Any]:
         from ..models.record_attachment_dto import RecordAttachmentDto
-        from ..models.record_relation_dto import RecordRelationDto
-        from ..models.record_authorization_dto import RecordAuthorizationDto
         from ..models.record_dto_tags import RecordDtoTags
+        from ..models.record_authorization_dto import RecordAuthorizationDto
+        from ..models.record_relation_dto import RecordRelationDto
         id = self.id
 
         title = self.title
@@ -115,7 +115,10 @@ class RecordDto:
         else:
             updated_by = self.updated_by
 
-        searchable = self.searchable
+        state: Union[Unset, int] = UNSET
+        if not isinstance(self.state, Unset):
+            state = self.state
+
 
         ttl: Union[None, Unset, int]
         if isinstance(self.ttl, Unset):
@@ -123,8 +126,6 @@ class RecordDto:
         else:
             ttl = self.ttl
 
-        archived = self.archived
-
         schema = self.schema
 
         content = self.content
@@ -188,12 +189,10 @@ class RecordDto:
             field_dict["createdBy"] = created_by
         if updated_by is not UNSET:
             field_dict["updatedBy"] = updated_by
-        if searchable is not UNSET:
-            field_dict["searchable"] = searchable
+        if state is not UNSET:
+            field_dict["state"] = state
         if ttl is not UNSET:
             field_dict["ttl"] = ttl
-        if archived is not UNSET:
-            field_dict["archived"] = archived
         if schema is not UNSET:
             field_dict["schema"] = schema
         if content is not UNSET:
@@ -218,9 +217,9 @@ class RecordDto:
     @classmethod
     def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
         from ..models.record_attachment_dto import RecordAttachmentDto
-        from ..models.record_relation_dto import RecordRelationDto
-        from ..models.record_authorization_dto import RecordAuthorizationDto
         from ..models.record_dto_tags import RecordDtoTags
+        from ..models.record_authorization_dto import RecordAuthorizationDto
+        from ..models.record_relation_dto import RecordRelationDto
         d = dict(src_dict)
         id = d.pop("id", UNSET)
 
@@ -288,7 +287,15 @@ class RecordDto:
         updated_by = _parse_updated_by(d.pop("updatedBy", UNSET))
 
 
-        searchable = d.pop("searchable", UNSET)
+        _state = d.pop("state", UNSET)
+        state: Union[Unset, RecordState]
+        if isinstance(_state,  Unset):
+            state = UNSET
+        else:
+            state = check_record_state(_state)
+
+
+
 
         def _parse_ttl(data: object) -> Union[None, Unset, int]:
             if data is None:
@@ -300,8 +307,6 @@ class RecordDto:
         ttl = _parse_ttl(d.pop("ttl", UNSET))
 
 
-        archived = d.pop("archived", UNSET)
-
         schema = d.pop("schema", UNSET)
 
         content = d.pop("content", UNSET)
@@ -368,9 +373,8 @@ class RecordDto:
             event_date=event_date,
             created_by=created_by,
             updated_by=updated_by,
-            searchable=searchable,
+            state=state,
             ttl=ttl,
-            archived=archived,
             schema=schema,
             content=content,
             attachments=attachments,
