@@ -1,8 +1,8 @@
 from typing import Literal, cast
 
-RecordState = Literal[0, 1, 2]
+RecordState = Literal[0, 1, 2, 3]
 
-RECORD_STATE_VALUES: set[RecordState] = { 0, 1, 2,  }
+RECORD_STATE_VALUES: set[RecordState] = { 0, 1, 2, 3,  }
 
 def check_record_state(value: int) -> RecordState:
     if value in RECORD_STATE_VALUES:
