@@ -6,6 +6,8 @@ from attrs import field as _attrs_field
 
 from ..types import UNSET, Unset
 
+from ..models.record_state import check_record_state
+from ..models.record_state import RecordState
 from ..types import UNSET, Unset
 from dateutil.parser import isoparse
 from typing import cast
@@ -14,9 +16,9 @@ from typing import Union
 import datetime
 
 if TYPE_CHECKING:
-  from ..models.record_relation_dto import RecordRelationDto
-  from ..models.record_authorization_dto import RecordAuthorizationDto
   from ..models.update_record_command_tags import UpdateRecordCommandTags
+  from ..models.record_authorization_dto import RecordAuthorizationDto
+  from ..models.record_relation_dto import RecordRelationDto
 
 
 
@@ -41,7 +43,8 @@ class UpdateRecordCommand:
             labels (Union[Unset, list[str]]):
             tags (Union[Unset, UpdateRecordCommandTags]):
             authorization (Union['RecordAuthorizationDto', None, Unset]):
-            archived (Union[Unset, bool]):
+            state (Union[Unset, RecordState]):
+            batch_process (Union[Unset, bool]):
      """
 
     id: Union[Unset, str] = UNSET
@@ -55,16 +58,17 @@ class UpdateRecordCommand:
     labels: Union[Unset, list[str]] = UNSET
     tags: Union[Unset, 'UpdateRecordCommandTags'] = UNSET
     authorization: Union['RecordAuthorizationDto', None, Unset] = UNSET
-    archived: Union[Unset, bool] = UNSET
+    state: Union[Unset, RecordState] = UNSET
+    batch_process: Union[Unset, bool] = UNSET
 
 
 
 
 
     def to_dict(self) -> dict[str, Any]:
-        from ..models.record_relation_dto import RecordRelationDto
-        from ..models.record_authorization_dto import RecordAuthorizationDto
         from ..models.update_record_command_tags import UpdateRecordCommandTags
+        from ..models.record_authorization_dto import RecordAuthorizationDto
+        from ..models.record_relation_dto import RecordRelationDto
         id = self.id
 
         title = self.title
@@ -120,7 +124,12 @@ class UpdateRecordCommand:
         else:
             authorization = self.authorization
 
-        archived = self.archived
+        state: Union[Unset, int] = UNSET
+        if not isinstance(self.state, Unset):
+            state = self.state
+
+
+        batch_process = self.batch_process
 
 
         field_dict: dict[str, Any] = {}
@@ -149,8 +158,10 @@ class UpdateRecordCommand:
             field_dict["tags"] = tags
         if authorization is not UNSET:
             field_dict["authorization"] = authorization
-        if archived is not UNSET:
-            field_dict["archived"] = archived
+        if state is not UNSET:
+            field_dict["state"] = state
+        if batch_process is not UNSET:
+            field_dict["batchProcess"] = batch_process
 
         return field_dict
 
@@ -158,9 +169,9 @@ class UpdateRecordCommand:
 
     @classmethod
     def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
-        from ..models.record_relation_dto import RecordRelationDto
-        from ..models.record_authorization_dto import RecordAuthorizationDto
         from ..models.update_record_command_tags import UpdateRecordCommandTags
+        from ..models.record_authorization_dto import RecordAuthorizationDto
+        from ..models.record_relation_dto import RecordRelationDto
         d = dict(src_dict)
         id = d.pop("id", UNSET)
 
@@ -253,7 +264,17 @@ class UpdateRecordCommand:
         authorization = _parse_authorization(d.pop("authorization", UNSET))
 
 
-        archived = d.pop("archived", UNSET)
+        _state = d.pop("state", UNSET)
+        state: Union[Unset, RecordState]
+        if isinstance(_state,  Unset):
+            state = UNSET
+        else:
+            state = check_record_state(_state)
+
+
+
+
+        batch_process = d.pop("batchProcess", UNSET)
 
         update_record_command = cls(
             id=id,
@@ -267,7 +288,8 @@ class UpdateRecordCommand:
             labels=labels,
             tags=tags,
             authorization=authorization,
-            archived=archived,
+            state=state,
+            batch_process=batch_process,
         )
 
         return update_record_command
